 uplclass Sequence:
    def __init__(self, seq=[]):
        if not isinstance(seq, list):
            raise ValueError("Sequence must be list.")
        elif len(seq) > 0:
            for block in seq:
                if not len(block) == 2:
                    raise ValueError("This isn't sequence.")
        self.seq = seq or []
    
    def __repr__(self):
        return f"Sequence({self.seq})"
    
    def append(self, name=None, count=0):
        if not isinstance(count, int) or count < 0:
            raise ValueError("Count must be non-negative integer.")
        self.seq.append([name, count])
    
    def insert(self, name=None, count=0, index=0):
        if not isinstance(count, int) or count < 0:
            raise ValueError("Count must be non-negative integer.")
        if not isinstance(index, int):
            raise ValueError("Index must be integer.")
        self.seq.insert(index, [name, count])
    
    def delete(self, index=0):
        del self.seq[index]
    
    def clip(self, indexes=[-1, 0]):
        if not isinstance(indexes[0], int) or not isinstance(indexes[1], int):
            raise ValueError("Every index must be integer.")
        elif not len(indexes) == 2:
            raise ValueError("You need to push only min and max index.")
        del self.seq[indexes[0]:indexes[1]+1]
    
    def get(self):
        return self.seq

    def scan(self, index=0):
        if not isinstance(index, int):
            raise ValueError("Index must be integer.")
        return self.seq[index]
    
    def multiple_scan(self, indexes=[-1, 0]):
        if not isinstance(indexes[0], int) or not isinstance(indexes[1], int):
            raise ValueError("Every index must be integer.")
        elif not len(indexes) == 2:
            raise ValueError("You need to push only min and max index.")
        return self.seq[indexes[0]:indexes[1]+1]

    def scan_cbn(self, name=None):
        names = []
        for block in self.seq:
            if block[0] == name:
                names.append(block[1])
        return names
    
    def scan_nbc(self, count=0):
        if not isinstance(count, int) or count < 0:
            raise ValueError("Count must be non-negative integer.")
        array = []
        for block in self.seq:
            if block[1] == count:
                array.append(block[0])
        return array
    
    def get_bwn(self, name=None):
        blocks = []
        for block in self.seq:
            if block[0] == name:
                blocks.append(block)
        return blocks
   
    def get_bwc(self, count=0):
        if not isinstance(count, int) or count < 0:
            raise ValueError("Count must be non-negative integer.")
        blocks = []
        for block in self.seq:
            if block[1] == count:
                blocks.append(block)
        return blocks
    
    def to_list(self):
        array = []
        for block in self.seq:
            for _ in range(block[1]):
                array.append(block[0])
        return array
    
    def add(self, seq=[]):
        if not isinstance(seq, list):
            raise ValueError("Sequence must be list.")
        elif len(seq) > 0:
            for block in seq:
                if not len(block) == 2:
                    raise ValueError("This isn't sequence.")
        self.seq += seq
   
    def __len__(self):
        return len(self.seq)

def to_sequence(list=[]):
    length = len(list)
    sequence = []
    current = list[0]
    count = 1
    for index in range(length):
        if index < length-1:
            if current == list[index+1]:
                count += 1
            else:
                sequence.append([current, count])
                count = 1
                current = list[index+1]
        else:
            sequence.append([current, count])
    return sequence
